Header

Struct Header 

pub struct Header {
    pub file_length: i32,
    pub bbox: BBoxZ,
    pub shape_type: ShapeType,
    pub version: i32,
}
struct representing the Header of a shapefile can be retrieved via the reader used to read

Fields

file_length: i32

Total file length (Header + Shapes) in 16bit word

bbox: BBoxZ

The bbox contained all the shapes in this shapefile

For shapefiles where the shapes do not have m or z values the associated min and max will be 0s.

shape_type: ShapeType

Type of all the shapes in the file (as mixing shapes is not allowed)

version: i32

Version of the shapefile specification

Implementations